@@ -24,11 +24,11 @@ class Base:
         self.selected_features_ = None
 
     def set_input_variables(
-        self,
-        features,
-        target,
-        feature_subset_include: Sequence = None,
-        feature_subset_exclude: Sequence = None,
+            self,
+            features,
+            target,
+            feature_subset_include: Sequence = None,
+            feature_subset_exclude: Sequence = None,
     ):
         try:
             if target.ndim != 1:
@@ -48,8 +48,8 @@ class Base:
         except AttributeError:
             pass
 
-        self.features = np.array(features)
-        self.target = np.array(target)
+        self.features = features
+        self.target = target
 
         self.check_feature_subsets(feature_subset_include, 'feature_subset_include')
         self.check_feature_subsets(feature_subset_exclude, 'feature_subset_exclude')
